@@ -1,6 +1,7 @@
 descr <- descriptives <- function(x, digits=4, errorOnFactor = FALSE,
                                   include=c("central tendency", "spread",
-                                            "range", "distribution shape", "sample size")) {
+                                            "range", "distribution shape", "sample size"),
+                                  t=FALSE, conf.level=.95) {
   varName <- deparse(substitute(x));
   if (is.factor(x)) {
     if (errorOnFactor) {
@@ -10,7 +11,7 @@ descr <- descriptives <- function(x, digits=4, errorOnFactor = FALSE,
     } else {
       return(freq(x));
     }
-  } else if (!is.vector(x, mode="numeric")) {
+  } else if (!is.numeric(x)) {
     stop("The first argument (called 'x' in this function, you passed '",
          varName, "') is not a numeric vector (it has class '",
          class(x), "').");
@@ -18,12 +19,14 @@ descr <- descriptives <- function(x, digits=4, errorOnFactor = FALSE,
     nrNA <- sum(is.na(x));
     x <- na.omit(x);
     mode <- modus(x);
+    meanCi <- formatCI(meanConfInt(x, conf.level=conf.level)$output$ci);
     if (length(mode) > 1) {
       mode <- vecTxt(mode);
     }
     res <- list("central tendency" = data.frame(mean = mean(x),
                                      median = median(x),
-                                     mode = mode),
+                                     mode = mode,
+                                     `meanCI` = meanCi),
                 spread = data.frame(var = var(x),
                                     sd = sd(x),
                                     iqr = median(x[x > median(x)]) -
@@ -35,24 +38,33 @@ descr <- descriptives <- function(x, digits=4, errorOnFactor = FALSE,
                                    max = max(x)),
                 "distribution shape" = data.frame(skewness = dataShape(x)$output$skewness,
                                    kurtosis = dataShape(x)$output$kurtosis,
-                                   dip = "TBA"),
+                                   dip = dip.test(x)$statistic[[1]]),
                 "sample size" = data.frame(total = length(x) + nrNA,
                                   "NA" = nrNA,
                                   valid = length(x)));
+    names(res[['central tendency']])[4] <- paste0(conf.level * 100, '% CI mean');
     attr(res, "varName") <- varName;
     attr(res, "digits") <- digits;
     attr(res, "include") <- include;
+    attr(res, "transpose") <- t;
     class(res) <- "descr";
     return(res);
   }
 }
 
 print.descr <- function(x, digits = attr(x, 'digits'),
+                        t = attr(x, 'transpose'),
                         row.names = FALSE, ...) {
   cat("###### Descriptives for", attr(x, "varName"), "\n\n");
-  for (current in names(x)) {
+  for (current in attr(x, "include")) {
     cat0("Describing the ", current, ":\n");
-    print(x[[current]], digits=digits, row.names=row.names, ...);
+    if (t) {
+      df <- t(x[[current]]);
+      colnames(df) <- '';
+      print(df, digits=digits, row.names=row.names, ...);
+    } else {
+      print(x[[current]], digits=digits, row.names=row.names, ...);
+    }
     cat("\n");
   }
   if ('shape' %in% names(x)) {
@@ -61,4 +73,16 @@ print.descr <- function(x, digits = attr(x, 'digits'),
         "more in depth.)");
   }
   invisible();
-}
\ No newline at end of file
+}
+
+### Function to smoothly pander descriptives from userfriendlyscience
+pander.descr <- function(x, headerPrefix = "",
+                         headerStyle = "**", ...) {
+  #pander(cat0(unlist(lapply(x, pander, ...)), sep="\n"));
+  pander(cat0(unlist(lapply(1:length(x), function(index) {
+    cat0("\n\n", headerPrefix, headerStyle,
+         "Describing the ", names(x)[index], ":",
+         headerStyle, "\n\n");
+    pander(x[[index]]);
+  }, ...)), sep="\n"));
+}
